band_rms

Function band_rms 

pub fn band_rms(
    frequency: &[f64],
    magnitude: &[f64],
    low: f64,
    high: f64,
) -> f64
The RMS amplitude of one band: sqrt(energy / bandwidth).

The effective amplitude every component in the band adds up to, in the same unit the magnitudes are in.