integral

Function integral 

pub fn integral(x: &[f64], y: &[f64]) -> Vec<f64>
The cumulative integral of y over x by the trapezoidal rule.

As long as the run it came from and starting at zero, so sample i is the area under the waveform up to x[i] — a charge from a current, a distance from a speed, an energy from a power.