papr

Function papr 

pub fn papr(
    frequency: &[f64],
    magnitude: &[f64],
    low: f64,
    high: f64,
) -> Option<f64>
The peak-to-average power ratio of one band, as a linear ratio.

High when a few components dominate, near one when the band is flat. In decibels it is 10 ยท log10 of this.